<?php
namespace Teknisa\CADCTB\Controllers;

use Zeedhi\Framework\DTO;
use Teknisa\Libs\Service\CRUD;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\CADCTB\Services\Ger03500ParametrosCentroDeCustoService;

/**
 * Class Ger03500ParametrosCentroDeCustoController
 * @package Teknisa\CADCTB\Controllers
 */
class Ger03500ParametrosCentroDeCustoController extends TeknisaCrud {

    protected $crudService;
    protected $parameterBag;
    protected $entityManager;
    protected $service;

    /**
     * @param CRUD                                   $crudService
     * @param ParameterBag                           $parameterBag
     * @param EntityManager                          $entityManager
     * @param Ger03500ParametrosCentroDeCustoService $service
     */
    public function __construct(CRUD $crudService, ParameterBag $parameterBag, EntityManager $entityManager, Ger03500ParametrosCentroDeCustoService $service) {
        $this->entityManager = $entityManager;
        $this->service       = $service;
    }

    /**
     * Gera Rateio de Centro de Custo
     */
    public function geraRateioCentroDeCusto(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataset()->getRows();
            
            $name    = $dataset[0][0];
            $tipo    = $dataset[1];
            $rateios = $dataset[2];
            
            $this->service->geraRateioCentroDeCusto($name, $tipo, $rateios);
        }catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    /**
     * Exclui Rateio de Centro de Custo
     */
    public function excluiRateioCentroDeCusto(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataset()->getRows();
            
            $name    = $dataset[0][0];
            $tipo    = $dataset[1];
            
            $this->service->excluiRateioCentroDeCusto($name, $tipo);
        }catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    /**
     * Cadastramento Automático Centro de Custo
     */
    public function geraCadastramentoAutomaticoCentroDeCusto(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataset()->getRows();
            
            $name = $dataset[0][0];
            $data = $dataset[1];
            
            $this->service->geraCadastramentoAutomaticoCentroDeCusto($name, $data);
        }catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}